@@ -32,6 +32,7 @@ from google.protobuf import text_format
 
 from tensorboard.backend.http_util import Respond
 from tensorboard.compat import tf
+from tensorboard.compat import _pywrap_tensorflow
 from tensorboard.plugins import base_plugin
 from tensorboard.plugins.projector.projector_config_pb2 import ProjectorConfig
 from tensorboard.util import tb_logging
@@ -295,6 +296,12 @@ class ProjectorPlugin(base_plugin.TBPlugin):
     new_thread.start()
     return False
 
+  def frontend_metadata(self):
+    return super(ProjectorPlugin, self).frontend_metadata()._replace(
+        element_name='vz-projector-dashboard',
+        disable_reload=True,
+    )
+
   def _determine_is_active(self):
     """Determines whether the plugin is active.
 
@@ -405,9 +412,9 @@ class ProjectorPlugin(base_plugin.TBPlugin):
         if ckpt_path:
           config.model_checkpoint_path = ckpt_path
 
-      # Sanity check for the checkpoint file.
+      # Sanity check for the checkpoint file existing.
       if (config.model_checkpoint_path and _using_tf() and
-          not tf.compat.v1.train.checkpoint_exists(config.model_checkpoint_path)):
+          not tf.io.gfile.glob(config.model_checkpoint_path + '*')):
         logger.warn('Checkpoint file "%s" not found',
                            config.model_checkpoint_path)
         continue
@@ -423,8 +430,7 @@ class ProjectorPlugin(base_plugin.TBPlugin):
     reader = None
     if config.model_checkpoint_path and _using_tf():
       try:
-        reader = tf.compat.v1.pywrap_tensorflow.NewCheckpointReader(
-            config.model_checkpoint_path)
+        reader = tf.train.load_checkpoint(config.model_checkpoint_path)
       except Exception:  # pylint: disable=broad-except
         logger.warn('Failed reading "%s"', config.model_checkpoint_path)
     self.readers[run] = reader
